Ext.ns('TYPO3.plupload.app')


TYPO3.plupload.app = {
	init:function() {
		this.initStore();
		this.initGrid();
		this.initViewport();
		this.initUploader();
		
	},
	initStore:function() {	
		var myData = new Array();				
		this.store = new Ext.data.ArrayStore({
			fields: [
				{name: 'id',     type:'string'},
				{name: 'filename'},
				{name: 'size',   type: 'float'},
				{name: 'upload', type: 'date'}
			]
		});
		this.store.loadData(myData);
	},
	initGrid:function() {
		this.grid = new Ext.grid.GridPanel({
			store     : this.store,
			stripeRows: true,
			stateful  : true,
			stateId   : 'grid',
			region    : 'center',
			//id        : 'grid',
			/*sm: new Ext.grid.RowSelectionModel({
				singleSelect: true,
			}),*/
			columns: [
				{header: 'id',     width: 20,   id:        'id',   hidden: true},
				{header: 'Name',   width: 200,  dataIndex: 'filename'},
				{header: 'Size',   width: 100,  dataIndex: 'size', renderer:function(value) {
						if(value<1024) {
							return value+'B';
						}
						if(value<1024*1024) {
							return Math.round(value/1024)+'KB';
						}
						if(value<1024*1024*1024){
							return Math.round(value/1024/1024)+'MB';
						}
						return Math.round(value/1024/1024/1024)+'GB';
					}
				},
				{header: 'Upload', width: 70,   dataIndex: 'upload', renderer:function(value) {
						if(value=='-') {
							return value;
						}
						return '<div class="progress"><div style="width:'+value+'%;"></div>';
					}
				}
			],
			// config options for stateful behavior
			tbar:[
				{
					text   :TYPO3.lang.SELECTFILES,
					id     : 'selectfiles',
					icon   :'sysext/t3skin/icons/module_file_list.gif',
					scope  :this,
					handler:function(e) {}
				},{
					text   :TYPO3.lang.STARTUPLOAD,
					icon   :'sysext/t3skin/icons/gfx/upload.gif',
					scope  :this,
					handler:function(e) {
						this.uploader.start();
					}
				},'->',{
					text   :TYPO3.lang.DROPFILE,
					icon   :'sysext/t3skin/icons/gfx/garbage.gif',
					scope  :this,
					handler:function(e) {
						sm  = this.grid.getSelectionModel();
						sel = sm.getSelected();
						if(sel.data.id!='') {
							//drop record from Grid
							recordId = this.store.findExact('id',sel.data.id);
							this.store.removeAt(recordId);
							this.store.commitChanges();
							this.grid.getView().refresh();
							//drop record from uploader
							this.uploader.removeFile(uploader.getFile(sel.data.id));
						}
					}
				}
			],
			bbar: [
				{
					xtype    :'menutextitem',
					contentEl:'filelist',
					text     :''
				}
			]
		});
	},
	initViewport:function() {
		this.viewport = new Ext.Viewport({
			layout  :'border',
			//renderTo:Ext.getBody(),
			items:[
				{
					region   :'north',
					xtype    :'panel',
					contentEl:'typo3-docheader',
					height   :50,
					border   :false
				},{
					region   :'east',
					xtype    :'panel',
					html     :'<div style="padding:25px;padding-top:40px;background-color:silver;background-color:white;background-image:url('+TYPO3.settings.plupload.pluploadpath+'/../background.png);background-repeat:no-repeat;height:100%;">'+TYPO3.lang.dropzone+'</div>',
					width    :200,
					hidden   :true,
					bbar     : [
						{
							xtype    :'progress',
							width    :190,
							value    :1,
							height   :14
						}
					]
				},
				this.grid
			]
		});
	},
	initUploader:function() {
		this.uploader = new plupload.Uploader({
			runtimes :            'html5,flash',
			browse_button :       'selectfiles',
			container :           'typo3-docbody',
			drop_element:         this.viewport.get(1).getEl().id,
			max_file_size :       '10mb',
			chunk_size :          '200kb',
			url :                 TYPO3.settings.plupload.pluploadpath+'/../upload.php?id='+TYPO3.settings.plupload.getid+'&be_typo_user='+TYPO3.settings.plupload.be_typo_user,
			flash_swf_url :       TYPO3.settings.plupload.pluploadpath+'/js/plupload.flash.swf',
			silverlight_xap_url : TYPO3.settings.plupload.pluploadpath+'/js/plupload.silverlight.xap',
			filters : [
				{title : TYPO3.lang.AllFiles  , extensions : "*"},
				{title : TYPO3.lang.ImageFiles, extensions : "jpg,gif,png"}						
			]/*,
			resize : {width : 1024, height : 1024, quality : 90}*/,
			app:this
		});

		this.uploader.bind('Init', function(up, params) {
			if(up.runtime == 'html5') {
				up.settings.app.viewport.get(1).show();
				up.settings.app.viewport.doLayout();
			}
			Ext.get('filelist').update("<div>&copy; <a href='http://www.kay-strobach.de' target='_blank'>Kay Strobach</a>, based on <a href='http://www.plupload.org' target='_blank'>PlUploader</a>, runtime: " + params.runtime + "</div>");
		});

		this.uploader.bind(
			'FilesAdded',
			this.listeners.filesAdded
		);

		this.uploader.bind(
			'UploadProgress',
			this.listeners.uploadProgress
		);
		
		
		this.uploader.bind(
			'UploadComplete',
			this.listeners.uploadComplete
		);
		

		this.uploader.init();
	},
	listeners: {
		filesAdded:function(up,files) {
			Ext.each(files, function(file,i) {
				fileRecord = new Ext.data.Record();
				fileRecord.set('id',      file.id);
				fileRecord.set('filename',file.name);
				fileRecord.set('size',    file.size);
				fileRecord.set('upload',  '-');
				up.settings.app.store.add(fileRecord);
				up.settings.app.store.commitChanges();
				up.settings.app.grid.getView().refresh();
			});
		},
		uploadProgress:function(up,file) {
			// Set file specific progress
			if(file.status==4) {
				Ext.Msg.alert('Upload Failed','Upload Failed for: '+file.name);
			}
			recordId = up.settings.app.store.findExact('id',file.id);
			if(recordId != -1) {
				up.settings.app.store.getAt(recordId).set('upload',file.percent);
			}
			up.settings.app.store.commitChanges();
			up.settings.app.grid.getView().refresh();
			up.settings.app.viewport.get(1).getBottomToolbar().get(0).show();
			up.settings.app.viewport.get(1).getBottomToolbar().get(0).updateProgress(
				(up.total.percent/100),
				up.total.percent+'%, '+Math.round(up.total.bytesPerSec/1000)+'kB/s'
			);
		},
		uploadComplete:function(up,files)  {
			top.TYPO3.Flashmessage.display(
				2,      //success
				TYPO3.lang.complete,
				up.total.uploaded+' '+TYPO3.lang.completeDescription,
				2);
		}
	}
}

// Custom example logic
	Ext.onReady(function() {
		TYPO3.plupload.app.init();		
	});